==> scichains-cv-4.4.2-sources.jar: net/algart/executors/modules/opencv/matrices/filtering/EqualizeHist.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2024 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.filtering;

import net.algart.executors.modules.opencv.common.VoidResultUMatFilter;
import net.algart.executors.modules.opencv.util.OTools;
import net.algart.executors.api.ReadOnlyExecutionInput;
import org.bytedeco.opencv.opencv_core.*;
import org.bytedeco.opencv.global.opencv_imgproc;

public final class EqualizeHist extends VoidResultUMatFilter implements ReadOnlyExecutionInput {
    private boolean autoConvertToGrayscale = false;

    public boolean isAutoConvertToGrayscale() {
        return autoConvertToGrayscale;
    }

    public void setAutoConvertToGrayscale(boolean autoConvertToGrayscale) {
        this.autoConvertToGrayscale = autoConvertToGrayscale;
    }

    @Override
    public void process(Mat result, Mat source) {
        Mat mat = source;
        try {
            if (autoConvertToGrayscale) {
                mat = OTools.toMono8UIfNot(mat);
            }
            opencv_imgproc.equalizeHist(mat, result);
        } finally {
            OTools.closeFirstIfDiffersFromSecond(mat, source);
        }
    }

    @Override
    public void process(UMat result, UMat source) {
        UMat mat = source;
        try {
            if (autoConvertToGrayscale) {
                mat = OTools.toMono8UIfNot(mat);
            }
            opencv_imgproc.equalizeHist(mat, result);
        } finally {
            OTools.closeFirstIfDiffersFromSecond(mat, source);
        }
    }
}

==> scichains-cv-4.4.13-sources.jar: net/algart/executors/modules/opencv/matrices/filtering/EqualizeHist.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2025 Daniel Alievsky, AlgART Laboratory (http://algart.net)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.algart.executors.modules.opencv.matrices.filtering;

import net.algart.executors.api.ReadOnlyExecutionInput;
import net.algart.executors.modules.opencv.common.VoidResultUMatFilter;
import net.algart.executors.modules.opencv.util.OTools;
import org.bytedeco.opencv.global.opencv_imgproc;
import org.bytedeco.opencv.opencv_core.Mat;
import org.bytedeco.opencv.opencv_core.UMat;

public final class EqualizeHist extends VoidResultUMatFilter implements ReadOnlyExecutionInput {
    private boolean autoConvertToGrayscale = false;

    public boolean isAutoConvertToGrayscale() {
        return autoConvertToGrayscale;
    }

    public void setAutoConvertToGrayscale(boolean autoConvertToGrayscale) {
        this.autoConvertToGrayscale = autoConvertToGrayscale;
    }

    @Override
    public void process(Mat result, Mat source) {
        Mat mat = source;
        try {
            if (autoConvertToGrayscale) {
                mat = OTools.toMono8UIfNot(mat);
            }
            opencv_imgproc.equalizeHist(mat, result);
        } finally {
            OTools.closeFirstIfDiffersFromSecond(mat, source);
        }
    }

    @Override
    public void process(UMat result, UMat source) {
        UMat mat = source;
        try {
            if (autoConvertToGrayscale) {
                mat = OTools.toMono8UIfNot(mat);
            }
            opencv_imgproc.equalizeHist(mat, result);
        } finally {
            OTools.closeFirstIfDiffersFromSecond(mat, source);
        }
    }
}
